/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A21: "ROTEMBERG WEIGHTS"

The table presents Rotemberg weights for the idustries (and industries by time period)
used in the construction of the exposure to robots measure, as explained
in Goldsmith-Pinkham, Sorkin and Swift (2018)
- Panel A: Long differences, 1990 - 2007
- Panel B: Stacked differences, 1990 - 2000 and 2000 - 2007

5.21.2018 (Revised 4/10/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*	Panel A : Rotember Weights for Long differences analysis: 1990 - 2007	   *
********************************************************************************

use "${project}/clean_data/apr_measures_ifr19", clear
* Reshape apr measure in wide format (required to use the bartik_weight command)
keep industry_ifr19 apr_${indmes}93_07
gen id=1
rename apr_${indmes}93_07_ apr_
reshape wide apr_, i(id) j(industry_ifr) string
tempfile apr
save `apr'

*Import Outcomes, Exposure measures for Long Difference analysis *
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
*Merge shares*
merge m:1 czone using "${project}/clean_data/${shares}.dta", assert(3) nogenerate
*Merge apr measure*
gen id=1
merge m:1 id using `apr', nogenerate

gen year=1990
tab division, gen(dum_div)

*Change name of variables for convenience in the use of the bartik_weight command
rename share_ind_* sh_*
foreach var of varlist sh_*{
replace `var'=0 if `var'==.
}

						
* Column 1 : Raw data, weighted by population
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
                weight_var(ipums_pop_1990) 
mat alpha_w_spec1 = r(alpha)

* Column 2 : Baseline Covariates, weighted by population
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
               controls($demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) 
mat alpha_w_spec2 = r(alpha)

* Column 3 : Excludes zones with highest exposure, weighted by population
preserve
keep if tag_exposure==1
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
               controls($demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) 
mat alpha_w_spec3 = r(alpha)
restore

* Column 4 : Excludes automotive manufacturing, weighted by population
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
               controls(sh_automotive $demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) 
mat alpha_w_spec4 = r(alpha)

* Column 5 : Unweighted, using baseline covariates
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
               controls($demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) 
mat alpha_w_spec5 = r(alpha)

* Column 6 : Unweighted, excludes automotive manufacturing
bartik_weight, z(sh_*) weightstub(apr_*) x(expof_${expomes}93_07) y(d_emppriv_1990_2008) ///
               controls(sh_automotive $demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) 
mat alpha_w_spec6 = r(alpha)

*** Stores weights in dataset ***
* List of industries
quietly: qui desc sh_*, varlist
local varlist = r(varlist)

clear
* Create Columns with weights for different Specification
svmat alpha_w_spec1
svmat alpha_w_spec2
svmat alpha_w_spec3
svmat alpha_w_spec4
svmat alpha_w_spec5
svmat alpha_w_spec6

* Generate variables for industry and years
quietly: gen ind = ""
quietly: gen year = ""
local t = 1
foreach var in `varlist' {
	quietly: replace ind = "`var'" if _n == `t'
	local t = `t' + 1
	}

rename *1 *	
sort alpha_w_spec1

* Identify maximum weight
egen max_alpha=rowmax(alpha_*)
* Keep if maximum weight for that industry is above 2 % in one of the specifications
keep if max_alpha>.02

gen indname=""
replace indname="Agriculture" if ind=="sh_agriculture"
replace indname="Automotive" if ind=="sh_automotive"
replace indname="Plastics and Chemicals" if ind=="sh_petrochemicals"
replace indname="Construction" if ind=="sh_construction"
replace indname="Education and Research" if ind=="sh_research"
replace indname="Electronics" if ind=="sh_electronics"
replace indname="Food and Beverages" if ind=="sh_food"
replace indname="Wood and Furniture" if ind=="sh_furniture"
replace indname="Minerals" if ind=="sh_mineral"
replace indname="Miscellaneous" if ind=="sh_manufacturing_other"
replace indname="Basic Metals" if ind=="sh_metal_basic"
replace indname="Industrial Machinery" if ind=="sh_metal_machinery"
replace indname="Metal products " if ind=="sh_metal_products"
replace indname="Mining" if ind=="sh_mining"
replace indname="Services" if ind=="sh_services"
replace indname="Paper and Printing" if ind=="sh_paper"
replace indname="Textiles" if ind=="sh_textiles"
replace indname="Utilities" if ind=="sh_utilities"
replace indname="Shipbuilding and Aerospace" if ind=="sh_vehicles_other"

foreach var of varlist alpha*{
replace `var'=floor(`var'*1000)/1000
}

* Export Panel A of Table A21
texsave_simple indname alpha_w_spec1 alpha_w_spec2 alpha_w_spec3 alpha_w_spec4 alpha_w_spec5 alpha_w_spec6 using "${project}/results/rotemberg_weights_longdifs.tex", replace  nonames frag

****************************************************************************************************
*	Panel B : Rotember Weights for Stacked differences analysis: 1990 - 2000 and 2000 - 2007	   *
****************************************************************************************************

use "${project}/clean_data/apr_measures_ifr19", clear
keep industry_ifr19 apr_${indmes}93_00 apr_${indmes}00_07

* Reshape apr measure in wide format (required to use the bartik_weight command)
rename apr_${indmes}93_00_ apr_1990
rename apr_${indmes}00_07_ apr_2000
reshape long apr_, i(industry_ifr) j(year)

reshape wide apr_, i(year) j(industry_ifr) string
tempfile apr
save `apr'

* Import outcome, exposure and covariates for stacked difference analysis*
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
*Merge shares*
if "${expomes}"=="updated"{
merge 1:1 czone year using "${project}/clean_data/${shares}_updated.dta", assert(3) nogenerate /*Shares updated*/
}
else {
merge m:1 czone using "${project}/clean_data/${shares}.dta", assert(3) nogenerate /*Shares fixed at 1970*/
}

*Merge apr measure*
sort czone year
merge m:1 year using `apr'

*Change name of variables for convenience in the use of the bartik_weight command
rename share_ind_* sh_*
foreach var of varlist sh_*{
replace `var'=0 if `var'==.
}


*Create period dummy for stacked difference analysis *
gen post_2000=(year==2000)

*Gen census division dumies *
tab division, gen(dum_div)

* Generate industry shares for the two periods of the stacked difference:
foreach var of varlist sh_*{
gen t90_`var'=`var'*(year==1990)
}
foreach var of varlist sh_*{
gen t00_`var'=`var'*(year==2000)
}

gen cars_1990=sh_automotive*(year==1990)
gen cars_2000=sh_automotive*(year==2000)
									
									
* Column 1 : Raw data, weighted by population
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
                controls(post_2000) weight_var(ipums_pop_1990) by(year)
mat alpha_w_spec1 = r(alpha)

* Column 2 : Baseline Covariates, weighted by population
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
               controls(post_2000 $demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) by(year)
mat alpha_w_spec2 = r(alpha) 

* Column 3 : Excludes zones with highest exposure, weighted by population
preserve
keep if tag_exposure==1
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
               controls(post_2000 $demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) by(year)
mat alpha_w_spec3 = r(alpha)
restore

* Column 4 : Excludes automotive manufacturing, weighted by population
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
               controls(post_2000 cars_* $demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) weight_var(ipums_pop_1990) by(year)
mat alpha_w_spec4 = r(alpha)

* Column 5 : Unweighted, using baseline covariates
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
               controls(post_2000 $demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) by(year)
mat alpha_w_spec5 = r(alpha)

* Column 6 : Unweighted, excludes automotive manufacturing
bartik_weight, z(t*_sh_*) weightstub(apr_*) x(expof_${expomes}) y(d_emppriv) ///
               controls(post_2000 cars_* $demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8) by(year)
mat alpha_w_spec6 = r(alpha)


*** Stores weights in dataset ***
* List of industries
quietly: qui desc t*_sh_*, varlist
local varlist = r(varlist)

* Create Columns with weights for different Specification
clear
svmat alpha_w_spec1
svmat alpha_w_spec2
svmat alpha_w_spec3
svmat alpha_w_spec4
svmat alpha_w_spec5
svmat alpha_w_spec6


* Generate variables for industry and years
quietly: gen ind = ""
quietly: gen year = ""
local t = 1
foreach var in `varlist' {
	if regexm("`var'", "t(.*)_sh_(.*)") {
		qui replace year = regexs(1) if _n == `t'
		qui replace ind = regexs(2) if _n == `t'
		}
	local t = `t' + 1
	}
	
rename *1 *	
sort alpha_w_spec1

* Identify maximum weight
egen max_alpha=rowmax(alpha_*)
* Keep if maximum weight for that industry is above 1 % in one of the specifications
keep if max_alpha>.01

gen indname=""
replace indname="Agriculture" if ind=="agriculture"
replace indname="Automotive" if ind=="automotive"
replace indname="Plastics and Chemicals" if ind=="petrochemicals"
replace indname="Construction" if ind=="construction"
replace indname="Education and Research" if ind=="research"
replace indname="Electronics" if ind=="electronics"
replace indname="Food and Beverages" if ind=="food"
replace indname="Wood and Furniture" if ind=="furniture"
replace indname="Minerals" if ind=="mineral"
replace indname="Miscellaneous" if ind=="manufacturing_other"
replace indname="Basic Metals" if ind=="metal_basic"
replace indname="Industrial Machinery" if ind=="metal_machinery"
replace indname="Metal products " if ind=="metal_products"
replace indname="Mining" if ind=="mining"
replace indname="Services" if ind=="services"
replace indname="Paper and Printing" if ind=="paper"
replace indname="Textiles" if ind=="textiles"
replace indname="Utilities" if ind=="utilities"
replace indname="Shipbuilding and Aerospace" if ind=="vehicles_other"

replace indname=indname+ " 90-00" if year=="90"
replace indname=indname+ " 00-07" if year=="00"

foreach var of varlist alpha*{
replace `var'=floor(`var'*1000)/1000
}

* Export Panel B of Table A21 (need texsave_simple.ado in your personal directory---slight modification of texsave that removes table preamble) *
texsave_simple indname alpha_w_spec1 alpha_w_spec2 alpha_w_spec3 alpha_w_spec4 alpha_w_spec5 alpha_w_spec6 using "${project}/results/rotemberg_weights_stacked.tex", replace  nonames frag


