/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A17 : "THE EFFECTS OF ROBOTS ON GOVERNMENT TRANSFERS"

The table presents estimates of the effects of robots on Government transfers
- Panel A: Change in total transfers per capita (2007 dollars)
- Panel B: Change in transfers per capita, SSA retirement benefits (2007 dollars)
- Panel C: Change in transfers per capita, SSA disability benefits (2007 dollars) 
- Panel D: Change in transfers per capita, TAA benefits (2007 dollars)
- Panel E: Change in transfers per capita, Unemployment benefits (2007 dollars)
- Panel F: Change in transfers per capita, education and tranining assistance (2007 dollars)
- Panel G: Change in transfers per capita, Medical benefits (2007 dollars)
- Panel H: Change in transfers per capita, Federal income assistance (2007 dollars)

5.21.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*
Loop through different outcome variables
- totindiv	 : total transfers per capita
- ssaret	 : SSA retirement benefits
- ssadis	 : SSA disability benefits
- taaimp	 : TAA benefits
- unemp		 : unemployment benefits
- totedu	 : education and training assistance
- totmed	 : medical benefits
- fedinc	 : Federal income assistance
*/

foreach depvar in totindiv ssaret ssadis taaimp unemp totedu totmed fedinc {

****** Columns 1 - 3 : Long differences, 1990 - 2007 *******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

replace d_trans_`depvar'_pc=(14/20)*d_trans_`depvar'_pc /*Convert to 14-year change*/
gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by population
reg d_trans_`depvar'_pc exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reg d_trans_`depvar'_pc exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3: Unweighted
reg d_trans_`depvar'_pc exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3long

****** Columns 4 - 6 : Stacked differences, 1990 - 2000 and 2000 - 2007 *******
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

replace d_trans_`depvar'_pc=(7/10)*d_trans_`depvar'_pc /*Convert to 7-year change*/
gen exposure_robots=expof_${expomes}
sort czone year 

* Column 4: Weighted by population
reg d_trans_`depvar'_pc exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reg d_trans_`depvar'_pc exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 6: Unweighted
reg d_trans_`depvar'_pc exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

*Export each Panel of Table A17 separatedly*
estout e1long e2long e3long e1stack e2stack e3stack using "$project/results/table_other_transfer_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

}



