/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A27: "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: ADDITIONAL COVARIATES"

The table presents estimates of the effects of exposure to robots on employment
and wages controlling for additional covariates:
- Panel A, D: state fixed effects
- Panel B, E: baseline employment level
- Panel C, F: changes in demographics

5.21.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

**********************************************************************************************
* Panel A - Change in Employment to population ratio - controlling for state fixed effects	**
**********************************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by Population (Baseline)
reg d_emppriv_1990_2008 exposure_robots $demographics $industry_shares $other_shocks i.statefip [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reg d_emppriv_1990_2008 exposure_robots $demographics $industry_shares $other_shocks i.statefip [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3 : Same weight to all czones 
reg d_emppriv_1990_2008 exposure_robots $demographics $industry_shares $other_shocks i.statefip, r cluster(state)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by Population 
reg d_emppriv exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked i.statefip i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reg d_emppriv exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked i.statefip i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6 : Same weight to all czones
reg d_emppriv exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked i.statefip i.year, r cluster(state)
estimates store e6

*Export Panel A of Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_state_employment.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


******************************************************************************************************
* Panel B - Change in Employment to population ratio - controlling for baseline employment level	**
******************************************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by Population (Baseline)
reg d_emppriv_1990_2008 base_emppriv exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reg d_emppriv_1990_2008 base_emppriv exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3 : Same weight to all czones 
reg d_emppriv_1990_2008 base_emppriv exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by Population
reg d_emppriv base_emppriv exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reg d_emppriv base_emppriv exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6 : Same weight to all czones
reg d_emppriv base_emppriv exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6

*Export Panel B of Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_ldv_employment.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


**************************************************************************************************
* Panel C - Change in Employment to population ratio - controlling for changes in demographics	**
**************************************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_2008.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

local demographics_list: subinstr global demographics "_1990" "", all
foreach var of local demographics_list{
gen change_demo_`var'=(`var'_2008-`var'_2000)+0.7*(`var'_2000-`var'_1990) /*Convert to 14 years changes*/ 
}

* Column 1 : Weighted by Population (Baseline)
reg d_emppriv_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reg d_emppriv_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3 : Same weight to all czones 
reg d_emppriv_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

*Create changes in demographics for covariates*
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2008.dta", assert(3) nogenerate

local demographics_list: subinstr global demographics "_1990" "", all
foreach var of local demographics_list{
gen change_demo_`var'=(`var'_2008-`var'_2000) if year==2000
replace change_demo_`var'=0.7*(`var'_2000-`var'_1990) if year==1990
}

* Column 4 : Weighted by Population
reg d_emppriv change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reg d_emppriv change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6 : Same weight to all czones
reg d_emppriv change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6

*Export Panel C, Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_changedemo_employment.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


********************************************************************************
* Panel D - Change in Log Hourly Wages - controlling for state fixed effects  **
********************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by Population (Baseline)
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics $industry_shares $other_shocks  [w=wage_earners_1990], absorb(statefip group_id) cluster(stcode)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics $industry_shares $other_shocks  [w=wage_earners_1990] if tag_exposure==1, absorb(statefip group_id) cluster(stcode)
estimates store e2

* Column 3 : Same weight to all czones 
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics $industry_shares $other_shocks  [w=nat_earners_weight_1990], absorb(statefip group_id) cluster(stcode)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
set matsize 5000
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by Population 
reghdfe d_hrwage_ln exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked i.year [w=wage_earners_1990], absorb(statefip i.group_id##i.year) cluster(stcode)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reghdfe d_hrwage_ln exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked i.year [w=wage_earners_1990] if tag_exposure==1, absorb(statefip i.group_id##i.year) cluster(stcode)
estimates store e5

* Column 6 : Same weight to all czones
reghdfe d_hrwage_ln exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked i.year [w=nat_earners_weight_1990], absorb(statefip i.group_id##i.year) cluster(stcode)
estimates store e6

*Export Panel D of Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_state_wages.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


**************************************************************************************
* Panel E - Change in Log Hourly Wages - controlling for baseline wage level	**
**************************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use czone base_wage_cz d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using "${project}/clean_data/outcomes_longdif_group.dta", clear
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by Population (Baseline)
reghdfe d_hrwage_ln_1990_2008 base_wage_cz exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 base_wage_cz exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2

* Column 3 : Same weight to all czones 
reghdfe d_hrwage_ln_1990_2008 base_wage_cz exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
use base_wage_cz czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using "${project}/clean_data/outcomes_stacked_group.dta", clear
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by Population
reghdfe d_hrwage_ln base_wage_cz exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reghdfe d_hrwage_ln base_wage_cz exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e5

* Column 6 : Same weight to all czones
reghdfe d_hrwage_ln base_wage_cz exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e6

*Export Panel E, Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_ldv_wages.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


**************************************************************************************
* Panel F - Change in Log hourly wages - controlling for changes in demographics	**
**************************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use czone d_hrwage_ln_1990_2008 base_* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2008.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Generate changes in demographics
local demographics_list: subinstr global demographics "_1990" "", all
foreach var of local demographics_list{
gen change_demo_`var'=(`var'_2008-`var'_2000)+0.7*(`var'_2000-`var'_1990) /*Convert to 14 years changes*/
}
encode state, gen(stcode)
encode group, gen(group_id)

* Column 1 : Weighted by Population (Baseline)
reghdfe d_hrwage_ln_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

* Column 2 : Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2

* Column 3 : Same weight to all czones 
reghdfe d_hrwage_ln_1990_2008 change_demo* exposure_robots $demographics $industry_shares $other_shocks $region_effects  [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
set matsize 5000
use czone year d_hrwage_ln base_* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

*Create changes in demographics *
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_2008.dta", assert(3) nogenerate

local demographics_list: subinstr global demographics "_1990" "", all
foreach var of local demographics_list{
gen change_demo_`var'=(`var'_2008-`var'_2000) if year==2000
replace change_demo_`var'=0.7*(`var'_2000-`var'_1990) if year==1990
}

* Column 4 : Weighted by Population
reghdfe d_hrwage_ln change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e4

* Column 5 : Excludes zones with highest exposure
reghdfe d_hrwage_ln change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e5

* Column 6 : Same weight to all czones
reghdfe d_hrwage_ln change_demo_* exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e6

*Export Panel E, Table A27*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_changedemo_wages.tex", style(tex) ///
varlabels(exposure_robots  "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


