/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A19 : "THE EFFECTS OF ROBOTS ON WAGE AND NON-WAGE INCOME"

The table presents estimates of the effects of exposure to robots on households' income
- Panel A: Change in log wage income per capita, BEA
- Panel B: Change in log wage income per capita, IRS
- Panel C: Change in log income per capita, BEA
- Panel D: Change in log non-wage income per capita, BEA

4/10/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*
Loop through different outcomes:
- bea_wages_pc 	: BEA log wage income per capita
- irs_wages		: IRS log wage income per capita
- bea_income_pc	: BEA log income per capita
- bea_other_pc	: BEA log non-wage income per capita
*/

foreach depvar in bea_wages_pc irs_wages bea_income_pc bea_other_pc {

***** Columns 1 - 3 : Long Differences, 1990 - 2007 *****

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1	: Weighted by population				  
reg d_`depvar' exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2	: Excludes zones with highest exposure
reg d_`depvar' exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3	: Unweighted
reg d_`depvar' exposure_robots  $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3


***** Columns 4 - 6 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Set panel structure for stacked differences analysis
xtset czone year, delta(10)
sort czone year
gen exposure_robots=expof_${expomes}

* Column 4	: Weighted by population				  
reg d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4

* Column 5	: Excludes zones with highest exposure
reg d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6 	: Unweighted
reg d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6

*Export each panel of Table A19, separatedly*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_income_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" logpop "Log of baseline population") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

}
