/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A7: "INDUSTRY-LEVEL RESULTS: LABOR SHARE, VALUE ADDED AND PRODUCTIVITY"

The table presents estimates of the relationship between adjusted penetration of
robots and changes in labor sharesand log value added across US industries

- Panel A: Change in labor share (in percentage points)
- Panel B: Change in log value added (percent annual change)
- Panel C: Change in log value added per worker (percent annual change)

5.26.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
use "${project}/clean_data/industry_data_ifr19", clear

********************************************************************************
*		Panel A:	Change in the Labor Share from BEA- IO Tables			   * 
********************************************************************************

gen change_beaio_1992_2007=100*(beaio_labsh07-beaio_labsh92)

*Column 1: Manufacturing dummy
reg change_beaio_1992_2007 apr_${indmes}93_07 manufacturing [w=beaio_VA92], r
estimates store e1

*Column 2: Manufacturing dummy + Light Manufacturing + Chinese imports
reg change_beaio_1992_2007 apr_${indmes}93_07 manufacturing light_manuf china_sag_iv_1991_2007 [w=beaio_VA92], r
estimates store e2

*Column 3: Manufacturing dummy + Light Manufacturing + Chinese import, Exclude Automotive
reg change_beaio_1992_2007 apr_${indmes}93_07 manufacturing light_manuf china_sag_iv_1991_2007 [w=beaio_VA92] if industry!="automotive", r
estimates store e3

*Column 4: Manufacturing dummy + Light Manufacturing + Chinese import, Unweighted
reg change_beaio_1992_2007 apr_${indmes}93_07 manufacturing light_manuf china_sag_iv_1991_2007, r
estimates store e4

*Export table*
estout e1 e2 e3 e4 using "$project/results/table_industry_dlabsh.tex", style(tex)  ///
varlabels(apr_${indmes}93_07_ "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(apr_${indmes}93_07_ ) ///
order(apr_${indmes}93_07_ )


********************************************************************************
*		Panel B:	Change in the Value Added from BEA- IO Tables			   * 
********************************************************************************

gen change_vadded_1992_2007=100*(ln(beaio_VA07)-ln(beaio_VA92))/15

*Column 1: Manufacturing dummy
reg change_vadded_1992_2007 apr_${indmes}93_07  manufacturing  [w=beaio_VA92], r
estimates store e1

*Column 2: Manufacturing dummy + Light Manufacturing + Chinese imports
reg change_vadded_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007 [w=beaio_VA92], r
estimates store e2

*Column 3: Manufacturing dummy + Light Manufacturing + Chinese import, Exclude Automotive
reg change_vadded_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007 [w=beaio_VA92] if industry!="automotive", r
estimates store e3

*Column 4: Manufacturing dummy + Light Manufacturing + Chinese import, Unweighted
reg change_vadded_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007, r
estimates store e4

*Export table*
estout e1 e2 e3 e4 using "$project/results/table_industry_vadded.tex", style(tex)  ///
varlabels(apr_${indmes}93_07_ "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(apr_${indmes}93_07_ ) ///
order(apr_${indmes}93_07_ )


********************************************************************************
* 	Panel C:	Change in the Value Added per Worker from BEA- IO Tables	   * 
********************************************************************************

gen change_vadded_pw_1992_2007=(100*ln(beaio_VA07/cbp_emp2007)-100*ln(beaio_VA92/cbp_emp1992))/15

*Column 1: Manufacturing dummy
reg change_vadded_pw_1992_2007 apr_${indmes}93_07  manufacturing  [w=beaio_VA92], r
estimates store e1

*Column 2: Manufacturing dummy + Light Manufacturing + Chinese imports
reg change_vadded_pw_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007 [w=beaio_VA92], r
estimates store e2

*Column 3: Manufacturing dummy + Light Manufacturing + Chinese import, Exclude Automotive
reg change_vadded_pw_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007 [w=beaio_VA92] if industry!="automotive", r
estimates store e3

*Column 4: Manufacturing dummy + Light Manufacturing + Chinese import, Unweighted
reg change_vadded_pw_1992_2007 apr_${indmes}93_07  manufacturing  light_manuf china_sag_iv_1991_2007, r
estimates store e4

*Export table*
estout e1 e2 e3 e4 using "$project/results/table_industry_vadded_pw.tex", style(tex)  ///
varlabels(apr_${indmes}93_07_ "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(apr_${indmes}93_07_ ) ///
order(apr_${indmes}93_07_ )

