/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A6: "ROBOTS AND LABOR DEMAND: CONTROL FOR OTHER INDUSTRY TRENDS"

The table presents estimates of the relationship between adjusted penetration of
robots and changes in log wage bill across US industries.

- Panel A: controls for the change in industry value added between 1992 and 2007
- Panel A' (not reported): instruments for the change in value added using task offshorability
- Panel B: instruments for the change in value added using intermediate imports in
		   supplier industries
- Panel C: controls for the share of offshorable jobs across industries
- Panel D: includes a dummy for industries with significant adoption of robots


5.21.2018 (revised 4/1/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*****************************************************************
**Panel A: Control for changes in value added from 1992 to 2007**
*****************************************************************

***********    Columns 1-3: Long differences	***************
use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 1: CBP log wage bill + manufacturing dummy + china + Value Added*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
reg depvar change_robots change_china manufacturing change_vadded [w=cbp_emp1993], r 
estimates store e1

*Column 2: NBER log wage bill within manufacturing + china + Value Added*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
reg depvar change_robots change_china  change_vadded [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER production workers within manufacturing log wage bill + china + Value Added*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
reg depvar change_robots change_china  change_vadded [w=nber_emp1993], r 
estimates store e3

***********     Columns 4-6: Stacked differences     ***************
use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1
*Value added trends*
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 4: CBP log wage bill + china + manufacturing dummy + value added *
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
reg depvar change_robots change_china manufacturing change_vadded i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

*Column 5: NBER within manufacturing log wage bill + china + value added*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
reg depvar change_robots change_china  change_vadded i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e5

*Column 6: NBER production workers within manufacturing + china + value added*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
reg depvar change_robots change_china  change_vadded i.period [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_trends_vadded.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" change_vadded "\multirow{2}{=}{Percent change in value added, 1992-2007}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots change_vadded) ///
order(change_robots change_vadded) 


**************************************************************************************************************
**Panel A' (not reported): Instrument changes in value added using task offshorability (reduces value added)**
**************************************************************************************************************

***** Columns 1-3: Long differences *****
use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 1: CBP log wage bill + manufacturing dummy + china + value added (inst.)*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
ivreg2 depvar change_robots change_china manufacturing (change_vadded=task_offshore_manuf) [w=cbp_emp1993], r 
estimates store e1

*Column 2: NBER log wage bill within manufacturing + china + value added (inst.)*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
ivreg2 depvar change_robots change_china  (change_vadded=task_offshore_manuf) [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER production workers within manufacturing + china + value added (inst.)*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
ivreg2 depvar change_robots change_china  (change_vadded=task_offshore_manuf) [w=nber_emp1993], r 
estimates store e3

*****  Columns 4-6: Stacked differences *****
use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1
*Value added trends*
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 4: CBP log wage bill + china + manufacturing dummy + value added (inst.)*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
ivreg2 depvar change_robots change_china manufacturing (change_vadded=task_offshore_manuf) i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

*Column 5: NBER log wage bill within manufacturing + china + value added (inst.)*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
ivreg2 depvar change_robots change_china  (change_vadded=task_offshore_manuf) i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e5

*Column 6: NBER log wage bill production workers within manufacturing + china + value added (inst.)*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
ivreg2 depvar change_robots change_china  (change_vadded=task_offshore_manuf) i.period [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_trends_vadded_iv_main.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" change_vadded "\multirow{2}{=}{Percent change in value added, 1992-2007}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2 widstat, fmt(%7.0f %7.2f %7.2f) labels("Observations" "R-squared" "First-stage F")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots change_vadded) ///
order(change_robots change_vadded) 

*************************************************************************************************
**Panel B: Instrument changes in value added using intermediate imports in supplier industries **
*************************************************************************************************

**************  Columns 1-3: Long differences  **************
use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 1: CBP log wage + manufacturing dummy + china*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
ivreg2 depvar change_robots change_china manufacturing (change_vadded=offshoringFH_1993_2007) [w=cbp_emp1993], r first
estimates store e1

*Column 2: NBER log wage within manufacturing + china*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
ivreg2 depvar change_robots change_china  (change_vadded=offshoringFH_1993_2007) [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER log wage production workers within manufacturing + china*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
ivreg2 depvar change_robots change_china  (change_vadded=offshoringFH_1993_2007) [w=nber_emp1993], r 
estimates store e3

**************  Columns 4-6: Stacked differences  **************
use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1
*Value added trends*
gen change_vadded=100*(ln(beaio_VA07)-ln(beaio_VA92))

*Column 4: CBP log wage bill + china + manufacturing dummy*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
ivreg2 depvar change_robots change_china manufacturing (change_vadded=offshoringFH_1993_2007) i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

*Column 5: NBER log wage bill within manufacturing + china*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
ivreg2 depvar change_robots change_china  (change_vadded=offshoringFH_1993_2007) i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e5

*Column 6: NBER log wage production workers within manufacturing + china*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
ivreg2 depvar change_robots change_china  (change_vadded=offshoringFH_1993_2007) i.period [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_trends_vadded_iv_alt.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" change_vadded "\multirow{2}{=}{Percent change in value added, 1992-2007}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2 widstat, fmt(%7.0f %7.2f %7.2f) labels("Observations" "R-squared" "First-stage F")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots change_vadded) ///
order(change_robots change_vadded) 


************************************************************************
**Panel C: Control for task offshorability in manufacturing industries**
************************************************************************

**************  Columns 1-3: Long differences    ***************

use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007

*Column 1: CBP log wage + manufacturing dummy + china + task offshorability in manuf.*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
reg depvar change_robots change_china manufacturing task_offshore_manuf [w=cbp_emp1993], r 
estimates store e1

*Column 2: NBER log wage within manufacturing + china + task offshorability in manuf.*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
reg depvar change_robots change_china  task_offshore_manuf [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER log wage production workers within manufacturing + china + task offshorability in manuf.*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
reg depvar change_robots change_china  task_offshore_manuf [w=nber_emp1993], r 
estimates store e3

**************   Columns 4-6: Stacked differences     ***************

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1

*Column 4: CBP log wage + china + task offshorability in manufacturing*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
reg depvar change_robots change_china manufacturing task_offshore_manuf i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

*Column 5: NBER log wage within manufacturing + china + task offshorability in manufacturing *
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
reg depvar change_robots change_china  task_offshore_manuf i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e5

*Column 6: NBER log wage of production workers within manufacturing + china + task offshorability in manufacturing*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
reg depvar change_robots change_china  task_offshore_manuf i.period [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_trends_offshore.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" task_offshore_manuf "\multirow{2}{=}{Share offshorable jobs in 1990}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots task_offshore_manuf) ///
order(change_robots task_offshore_manuf) 


************************************************************************
**Panel D: Control for industries with significant adoption of robots **
************************************************************************

**************  Columns 1-3: Long differences    ***************

use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007

*Column 1: CBP log wage + manufacturing dummy + china + high usage of robots*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
reg depvar change_robots change_china manufacturing high_usage [w=cbp_emp1993], r 
estimates store e1

*Column 2: NBER log wage within manufacturing + china + high usage of robots*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
reg depvar change_robots change_china  high_usage [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER log wage of production workers within manufacturing + china + high usage of robots*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
reg depvar change_robots change_china  high_usage [w=nber_emp1993], r 
estimates store e3

**************   Columns 4-6: Stacked differences     ***************

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1

*Column 4: CBP log wage + manufacturing dummy + china + high usage of robots*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
reg depvar change_robots change_china manufacturing high_usage i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

*Column 5: NBER log wage within manufacturing + china + high usage of robots*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
reg depvar change_robots change_china  high_usage i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e5

*Column 6: NBER log wage of production workers within manufacturing + china + high usage of robots*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
reg depvar change_robots change_china  high_usage i.period [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_trends_high_usage.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" high_usage "\multirow{2}{=}{Industries with applications for robots}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots) ///
order(change_robots) 






