/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A2: "ADJUSTED PENETRATION OF ROBOTS IN THE US AND IN EUROPE"

The table presents estimates of the relationship between adjusted penetration of
robots from Euro 5 and the penetration of robots in the US for different periods

- Panel A: 1993 - 2007
- Panel B: 2000 - 2007
- Panel C: 2004 - 2007
- Panel D: 2000 - 2014

5.26.2018 (revised 4/1/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*					Panel A:	Period from 1993 to 2007 					   * 
********************************************************************************

use "${project}/clean_data/industry_data_ifr19", clear

********* Columns 1-3, Adjusted penetration of Robots ***********
gen adoption_us=14*apr_us_adj04_07_/3
gen exposure_robots=apr_${indmes}93_07

* Column 1: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e1

* Column 2: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e2

* Column 3: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e3

********* Columns 4-6, Penetration of Robots (raw) ***********
replace adoption_us=14*apr_us_lv04_07_/3

* Column 4: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e4

* Column 5: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e5

* Column 6: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e6

*Export table*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_first_stage_93_07.tex", style(tex)  ///
varlabels(exposure_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)

********************************************************************************
*					Panel B:	Period from 2000 to 2007 					   * 
********************************************************************************

use "${project}/clean_data/industry_data_ifr19", clear

********* Columns 1-3, Adjusted penetration of Robots ***********
gen adoption_us=7*apr_us_adj04_07_/3
gen exposure_robots=apr_${indmes}00_07

* Column 1: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e1

* Column 2: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e2

* Column 3: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e3


********* Columns 4-6, Penetration of Robots (raw) *************
replace adoption_us=7*apr_us_lv04_07_/3

* Column 4: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e4

* Column 5: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e5

* Column 6: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e6


*Export table*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_first_stage_00_07.tex", style(tex)  ///
varlabels(exposure_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)

********************************************************************************
*					Panel C:	Period from 2004 to 2007 					   * 
********************************************************************************
use "${project}/clean_data/industry_data_ifr19", clear

********* Columns 1-3, Adjusted penetration of Robots ***********
gen adoption_us=apr_us_adj04_07_
gen exposure_robots=apr_${indmes}04_07

* Column 1: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e1

* Column 2: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e2

* Column 3: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e3

********* Columns 4-6, Penetration of Robots (raw) *************
replace adoption_us=apr_us_lv04_07_

* Column 4: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e4

* Column 5: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e5

* Column 6: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e6


*Export table*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_first_stage_04_07.tex", style(tex)  ///
varlabels(exposure_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)


********************************************************************************
*					Panel D:	Period from 2004 to 2014 					   * 
********************************************************************************

use "${project}/clean_data/industry_data_ifr19", clear

********* Columns 1-3, Adjusted penetration of Robots ***********
gen adoption_us=14*apr_us_adj04_14_/10
gen exposure_robots=apr_${indmes}00_14

* Column 1: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e1

* Column 2: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e2

* Column 3: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e3

********* Columns 4-6, Penetration of Robots (raw) *************
replace adoption_us=14*apr_us_lv04_14_/10

* Column 4: Robots Penetration in EURO5
reg adoption_us exposure_robots [w=emp_us], r
estimates store e4

* Column 5: Robots Penetration in EURO5, manufacturing dummy
reg adoption_us exposure_robots manufacturing [w=emp_us], r
estimates store e5

* Column 6: Robots Penetration in EURO5, manufacturing dummy, unweighted
reg adoption_us exposure_robots manufacturing, r
estimates store e6


*Export table*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_industry_first_stage_00_14.tex", style(tex)  ///
varlabels(exposure_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)

