/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A8 : "EXPOSURE TO ROBOTS AND THE LOCATION OF INTEGRATORS"

The tables present estimates of the relationship between exposure to robots and 
the location of robot integrators.

5.21.2018 (Revised 4/9/2018)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

************* Panel A : Log of one plus number of integrators ******************

use   "${project}/clean_data/czones_integrators.dta", clear /*Cannot be shared, please contact Nancey Green Leigh for data */
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

*Column 1: Census divisions
reg log_num_int expof_${expomes}93_07 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Census divisions + Demographic characteristics
reg log_num_int expof_${expomes}93_07 $demographics $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2

*Column 3: Census divisions + Demographic characteristics + Industry Shares
reg log_num_int expof_${expomes}93_07 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3

*Column 4: Census divisions + Demographic characteristics + Industry Shares + Chinese imports + Share of routine jobs
reg log_num_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e4

*Column 5: Same controls as column 4 but excluding zones with highest exposure
reg log_num_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Column 6: Same controls as column 4 estimates Same weight to all czones
reg log_num_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects , r cluster(state)
estimates store e6

*Export Table A8, Panel A*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_integrators_log.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 


*************** Panel B : Log of one plus number of integrators *****************
****** Separate the effect of automotive industries from other industries ******

*Column 1: Census divisions
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Census divisions + Demographic characteristics
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $demographics $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2

*Column 3: Census divisions + Demographic characteristics + Industry Shares 
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3

*Column 4: Census divisions + Demographic characteristics + Industry Shares + Chinese imports + Share of routine jobs 
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e4

*Column 5: Same controls as column 4 but excluding zones with highest exposure
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Column 6: Same controls as column 4 estimates Same weight to all czones
reg log_num_int expon_${expomes}93_07 expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects , r cluster(state)
estimates store e6

*Export Table A8, Panel B*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_integrators_cars.tex", style(tex) ///
varlabels(expon_${expomes}93_07 "\multirow{2}{=}{Exposure to robots in other industries}" expoc_${expomes}93_07 "\multirow{2}{=}{Exposure to robots in automotive industries}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expoc_${expomes}93_07 expon_${expomes}93_07) ///
order(expoc_${expomes}93_07 expon_${expomes}93_07) 



************* Panel C : Log of one plus employment in integrators **************

*Column 1: Census divisions
reg log_emp_int expof_${expomes}93_07 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Census divisions + Demographic characteristics
reg log_emp_int expof_${expomes}93_07 $demographics $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2
 
*Column 3: Census divisions + Demographic characteristics + Industry Shares 
reg log_emp_int expof_${expomes}93_07 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3

*Column 4: Census divisions + Demographic characteristics + Industry Shares + Chinese imports + Share of routine jobs 
reg log_emp_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e4

*Column 5: Same controls as column 4 but excluding zones with highest exposure
reg log_emp_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Column 6: Same controls as column 4 estimates Same weight to all czones
reg log_emp_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects , r cluster(state)
estimates store e6

*Export Table 6, Panel C*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_integrators_emp.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 

*************** Panel D : Dummy for location of integrators *****************

*Column 1: Census divisions
reg dum_int expof_${expomes}93_07 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Census divisions + Demographic characteristics
reg dum_int expof_${expomes}93_07 $demographics $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2
 
*Column 3: Census divisions + Demographic characteristics + Industry Shares  
reg dum_int expof_${expomes}93_07 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3
 
*Column 4: Census divisions + Demographic characteristics + Industry Shares + Chinese imports + Share of routine jobs  
reg dum_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e4

*Column 5: Same controls as column 4 but excluding zones with highest exposure
reg dum_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Column 6: Same controls as column 4 estimates Same weight to all czones
reg dum_int expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects , r cluster(state)
estimates store e6

*Export Table 6, Panel D*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_integrators_dummy.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 


