/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A13 : "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: RECENT PERIODS"

The table presents estimates of the effects of exposure to robots on employment
and wages for different periods of time.
- Panel A: Long-differences estimates, 1990 - 2014
- Panel B: Long-differences estimates, 1990 - 2010
- Panel C: Long-differences estimates, 2000 - 2014
- Panel D: Long-differences estimates, 2000 - 2007
- Panel E: Long-differences estimates, 2000 - 2010

5.21.2018 (Revised 4/9/219)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************
* Panel A:	Long differences 1990-2014				   *
********************************************************

****** Columns 1 - 3 : Change in employment to population ratio ******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Column 1 : Weighted by population
reg d_emppriv_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure
reg d_emppriv_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Unweighted
reg d_emppriv_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

****** Columns 4 - 6 : Change in log hourly wages  ******
use czone d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_14 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by population
reghdfe d_hrwage_ln_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Unweighted
reghdfe d_hrwage_ln_1990_2014 expof_${expomes}93_14 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A13, Panel A*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_longdif_93_14.tex", style(tex) ///
varlabels(expof_${expomes}93_14 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_14) ///
order(expof_${expomes}93_14) 


********************************************************
* Panel B: 	Long differences 1990-2010				   *
********************************************************

****** Columns 1 - 3 : Change in employment to population ratio ******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Column 1 : Weighted by population
reg d_emppriv_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure
reg d_emppriv_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Unweighted
reg d_emppriv_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

****** Columns 4 - 6 : Change in log hourly wages  ******
use czone d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_10 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by population
reghdfe d_hrwage_ln_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Unweighted
reghdfe d_hrwage_ln_1990_2011 expof_${expomes}93_10 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A13, Panel B*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_longdif_93_10.tex", style(tex) ///
varlabels(expof_${expomes}93_10 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_10) ///
order(expof_${expomes}93_10) 



********************************************************
* Panel C: 	Long differences 2000-2014				   *
********************************************************

****** Columns 1 - 3 : Change in employment to population ratio ******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate

* Column 1 : Weighted by population
reg d_emppriv_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure
reg d_emppriv_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Unweighted
reg d_emppriv_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects, r cluster(state)
estimates store e3

****** Columns 4 - 6 : Change in log hourly wages  ******
use czone d_hrwage_ln* nat_earners_weight_2000 wage_earners_2000 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}00_14 $other_shocks_2000)
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by population
reghdfe d_hrwage_ln_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Unweighted
reghdfe d_hrwage_ln_2000_2014 expof_${expomes}00_14 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=nat_earners_weight_2000], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A13, Panel C*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_longdif_00_14.tex", style(tex) ///
varlabels(expof_${expomes}00_14 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}00_14) ///
order(expof_${expomes}00_14) 


********************************************************
* Panel D: 	Long differences 2000-2007				   *
********************************************************

****** Columns 1 - 3 : Change in employment to population ratio ******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate

* Column 1 : Weighted by population
reg d_emppriv_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure
reg d_emppriv_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Unweighted
reg d_emppriv_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects, r cluster(state)
estimates store e3

****** Columns 4 - 6 : Change in log hourly wages  ******
use czone d_hrwage_ln* nat_earners_weight_2000 wage_earners_2000 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}00_07 $other_shocks_2000)
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by population
reghdfe d_hrwage_ln_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Unweighted
reghdfe d_hrwage_ln_2000_2008 expof_${expomes}00_07 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=nat_earners_weight_2000], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A13, Panel D*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_longdif_00_07.tex", style(tex) ///
varlabels(expof_${expomes}00_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}00_07) ///
order(expof_${expomes}00_07) 



********************************************************
* Panel D: 	Long differences 2000-2010				   *
********************************************************

****** Columns 1 - 3 : Change in employment to population ratio ******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate

* Column 1 : Weighted by population
reg d_emppriv_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure
reg d_emppriv_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=ipums_pop_2000] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Unweighted
reg d_emppriv_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects, r cluster(state)
estimates store e3

****** Columns 4 - 6 : Change in log hourly wages  ******
use czone d_hrwage_ln* nat_earners_weight_2000 wage_earners_2000 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}00_10 $other_shocks_2000)
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by population
reghdfe d_hrwage_ln_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=wage_earners_2000] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Unweighted
reghdfe d_hrwage_ln_2000_2011 expof_${expomes}00_10 $demographics_2000 $industry_shares_2000 $other_shocks_2000 $region_effects [w=nat_earners_weight_2000], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A13, Panel E*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_longdif_00_10.tex", style(tex) ///
varlabels(expof_${expomes}00_10 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}00_10) ///
order(expof_${expomes}00_10) 


