/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A33: "OLS ESTIMATES OF THE RELATIONSHIP BETWEEN US EXPOSURE TO ROBOTS AND 
			EMPLOYMENT AND WAGES"

The table presents OLS estimates corresponding to the IV models in Table 7.

- Panel A: Long-differences between 1990 and 2007
- Panel B: Long-differences between 1990 and 2007, alternative imputation of US exposure
- Panel C: Long-differences between 1990 and 2014
- Panel D: Long-differences between 2000 and 2007
- Panel E: Long-differences between 2000 and 2014

5.21.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

**********************************************
**Loop over all periods presented in Table 7**
**********************************************
foreach time in 93_07 93_07_alt  93_14 00_07  00_14{


********************************************************************************
********* Columns 1 - 3 : Change in Employment to Population Ratio *************
***************************   Long Differences   *******************************

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate

* I) Import covariates measured at the beginning of the analysis period
* II) Identify dependent variable as change in employment to population ratio
* III) Convert adoption measure to XX-years difference to reflect the change in the dependent variable
* IV) Identify the weights for the regression and define macro for controls
if "`time'"=="93_07"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*14/3 /*convert to a 14-year equivalent change*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_07_alt"{
local period 93_07
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*4.5   /*APR in US 93-07 was of 0.77 
                                            (1 robot per k workers minus adjustment term of -0.33*ln(14.48/6.88))
										    APR in US 04-07 was of 0.17
                                            (0.33 robot per k workers minus adjustment term of -1*ln(14.48/12.27))*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}

else if "`time'"=="93_14"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2014
gen us_adoption=(expof_${usmes}04_14)*21/10 /*convert to a 21-year equivalent change*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="00_07"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_emppriv_2000_2008
gen us_adoption=(expof_${usmes}04_07)*7/3 /*convert to a 7-year equivalent change*/
gen wvar=ipums_pop_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}
else if "`time'"=="00_14"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_emppriv_2000_2014
gen us_adoption=(expof_${usmes}04_14)*14/10 /*convert to a 14-year equivalent change*/
gen wvar=ipums_pop_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}

*Column 1: Division dummies *
reg depvar us_adoption $region_effects [w=wvar], r cluster(state) 
estimates store e1

*Column 2: Division dummies + Baseline Covariates*
reg depvar us_adoption `controls_period' $region_effects [w=wvar], r cluster(state) 
estimates store e2

*Column 3: Division dummies + Baseline Covariates + Chinese imports and Share of employment in Routine Jobs
reg depvar us_adoption `controls_period'  `other_period'  $region_effects [w=wvar], r cluster(state) 
estimates store e3

********************************************************************************
********* 			Columns 4 - 6 : Change in Log Hourly Wages	   *************
***************************   Long Differences   *******************************

use czone d_hrwage_ln_* wage_earners_* group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks $other_shocks_2000 expof_${usmes}* expof_${expomes}`period')

* I) Import covariates measured at the beginning of the analysis period
* II) Identify dependent variable as change in employment to population ratio
* III) Convert adoption measure to XX-years difference to reflect the change in the dependent variable
* IV) Identify the weights for the regression and define macro for controls
if "`time'"=="93_07"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*14/3 /*convert to a 14-year equivalent change*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_07_alt"{
local period 93_07
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*4.5   /*APR in US 93-07 was of 0.77 
                                            (1 robot per k workers minus adjustment term of -0.33*ln(14.48/6.88))
										    APR in US 04-07 was of 0.17
                                            (0.33 robot per k workers minus adjustment term of -1*ln(14.48/12.27))*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_14"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2014
gen us_adoption=(expof_${usmes}04_14)*21/10 /*convert to a 21-year equivalent change*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="00_07"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_2000_2008
gen us_adoption=(expof_${usmes}04_07)*7/3 /*convert to a 7-year equivalent change*/
gen wvar=wage_earners_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}
else if "`time'"=="00_14"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_2000_2014
gen us_adoption=(expof_${usmes}04_14)*14/10 /*convert to a 14-year equivalent change*/
gen wvar=wage_earners_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}


encode state, gen(stcode)
encode group, gen(group_id)

*Column 4: Division dummies *
reghdfe depvar $region_effects  us_adoption [w=wvar], a(group_id) vce(cluster stcode) 
estimates store e4

*Column 5: Division dummies + Baseline Covariates*
reghdfe depvar `controls_period' $region_effects us_adoption [w=wvar], a(group_id) vce(cluster stcode) 
estimates store e5

*Column 6: Division dummies + Baseline Covariates + Chinese imports and Share of employment in Routine Jobs
reghdfe depvar  `controls_period'  `other_period'  $region_effects us_adoption [w=wvar], a(group_id) vce(cluster stcode) 
estimates store e6

*Export each Panel of Table A33 separatedly*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_ols_`time'.tex", style(tex) ///
varlabels(us_adoption "US exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f ) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(us_adoption) ///
order(us_adoption)


}


