/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A16 : "THE EFFECT OF ROBOTS ON WAGES: ADDITIONAL OUTCOMES"

The table presents estimates of the effects of exposure to robots on several
labor market outcomes.
- Panel A: Change in log weekly wages
- Panel B: Change in log yearly wages
- Panel C: Change in hourly wages (2007 dollars)
- Panel D: Change in log wage bill (from the CBP)
			
5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


/***** Loop through alternative measures of wages from Census 
wlwage_ln : Log weekly wages
yrwage_ln : Log yearly wages
hrwage	  : Hourly wages (2007 dollars)
******/
foreach depvar in wkwage_ln yrwage_ln hrwage  {

****** Columns 1 - 3 : Long differences, 1990 - 2007 ********
use czone d_`depvar'_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07  $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by population
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1long

* Column 2 : Excludes zones with highest exposure
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2long

* Column 3 : Unweighted
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3long

****** Columns 4 - 6 : Stacked differences, 1990 - 2000 and 2000 - 2007 ********
set matsize 5000
use czone year d_`depvar'* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}  $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by population
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e1stack

* Column 5 : Excludes zones with highest exposure
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e2stack

* Column 6 : Unweighted
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e3stack

*Export Panels A, B, C of table A16 separatedly*
estout e1long e2long e3long e1stack e2stack e3stack using "$project/results/table_other_outcomes_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 
}



********************************************************************************
*** Panel D. Change in log wage bill from the CBP							****
********************************************************************************

****** Columns 1 - 3 : Long differences, 1990 - 2007 ********
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by population
reg d_cbp_wages_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2 : Excludes zones with highest exposure
reg d_cbp_wages_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3 : Unweighted
reg d_cbp_wages_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3long

****** Columns 4 - 6 : Stacked differences, 1990 - 2000 and 2000 - 2007 ********
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4 : Weighted by population
reg d_cbp_wages exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 5 : Excludes zones with highest exposure
reg d_cbp_wages exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 6 : Unweighted
reg d_cbp_wages exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

*Export Panel D of table A16*
estout e1long e2long e3long e1stack e2stack e3stack  using "$project/results/table_other_outcomes__cbp_wages.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 
