/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A20: "PRE-TRENDS 1970 - 1990: ADDITIONAL OUTCOMES"

The table presents estimates of the effects of exposure to robots on past outcomes
measured in the 1970 - 1990 period.
- Panel A: Change in manufacturing employment to population ratio
- Panel B: Change in the employment to population ratio, including public sector and self-employment.
- Panel C: Change in non-participation rate.
- Panel D: Change in unemployment rate.
- Panel E: Change in log weekly wages.

5.21.2018 (Revised 4/10/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
* 						Panels: A, B, C, D							*
********************************************************************************

/* 
Loop through the different outcomes except for log weekely wages:
- empman	: Manufacturing employment to population ratio
- empraw	: Employment to population ratio, including public sector and self-employment
- nonpart	: Non-participation rate
- urate		: Unemployemtn rate
*/

foreach depvar in  empman empraw nonpart urate  {

***************    Long differences  1970 - 1990    ***************
use "${project}/clean_data/outcomes_placebo_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate

* Column 1 : Census Dummies
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e1

* Column 2 : Census Dummies and Demographics
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $demographics_1970 $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e2

* Column 3 : Census Dummies, Demographics and Industry shares
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e3

* Column 4 : Census Dummies, Demographics, Industry shares, Chinese imports and share of employment in Routine jobs
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e4

* Column 5 : Same controls as column 4 excluding zones with highest exposure
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=ipums_pop_1970] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6 : Same controls as column 4, Same weight to all czones
reg d_`depvar'_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects, r cluster(state)
estimates store e6

*Export Panels A, B, C, D and F of Table A20 separatedly*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_placebo_`depvar'.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07 ) ///
order(expof_${expomes}93_07 ) 
}

********************************************************************************
* 					Panel E : Change in log weekly wages				       *
********************************************************************************

foreach depvar in wkwage_ln {

***************    Long differences  1970 - 1990    ***************
use "${project}/clean_data/outcomes_placebo_group.dta", clear
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)
gen detroit=(czone==11600)

* Column 1 : Census Dummies
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e1

* Column 2 : Census Dummies and Demographics
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $demographics_1970 $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e2

* Column 3 : Census Dummies, Demographics and Industry shares
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e3

* Column 4 : Census Dummies, Demographics, Industry shares, Chinese imports and share of employment in Routine jobs
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e4

* Column 5 : Same controls as column 4 excluding zones with highest exposure
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=wage_earners_1970] if tag_exposure==1, absorb(i.group_id) cluster(stcode)
estimates store e5

* Column 6 : Same controls as column 4, Same weight to all czones
reghdfe d_`depvar'_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=nat_earners_weight_1970], absorb(i.group_id) cluster(stcode)
estimates store e6

*Export Panel E, Table A20*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_placebo_`depvar'.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07 ) ///
order(expof_${expomes}93_07 ) 

}
