/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file executes the empirical analysis reported both in the main text and in the appendix

Before launching the file, please set the working directory at line 14: 
for example global project "C:\Users\Yourname\Folder\Repkit_Robots_and_Jobs"

Pascual Restrepo (5.17.2019)
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*Directory*
set matsize 5000
global project "C:/Users/Pascual Restrepo/Dropbox/Research/robots_jobs_jpe/replication_kit"

*Details for measure of exposure to robots*
global indmes  euro5_qo
global expomes euro5_qo
global usmes   us_adj
global shares  czone_shares_ifr19

*covariates for 1990*
global demographics    ipums_female_1990 ipums_hispanic_1990 ipums_white_1990 ipums_black_1990 ipums_asian_1990 ipums_highschool_1990 ipums_college_1990 ipums_masters_1990 ipums_above65_1990 ipums_logpop_1990
global industry_shares ind_share_manufacturing_1990 ind_share_manufacturing_f_1990 ind_share_light_manuf_1990
global other_shocks    chinashock_iv_90_07 expo_share_occ_routine_1990 
global region_effects  i.division

*covariates for 1970*
global industry_shares_1970: 	subinstr global industry_shares "_1990" "_1970", all
global demographics_1970: 		subinstr global demographics "_1990" "_1970", all

*covariates for 2000*
global industry_shares_2000: 	subinstr global industry_shares "_1990" "_2000", all
global demographics_2000: 		subinstr global demographics "_1990" "_2000", all
global other_shocks_2000:  		subinstr global other_shocks "_90_07" "_2000", all
global other_shocks_2000:  		subinstr global other_shocks_2000 "_1990" "_2000", all

*covariates stacked models*
global industry_shares_stacked: subinstr global industry_shares "_1990" "", all
global demographics_stacked: 	subinstr global demographics "_1990" "", all
global other_shocks_stacked: 	subinstr global other_shocks "_90_07" "", all
global other_shocks_stacked: 	subinstr global other_shocks_stacked "_91_07" "", all
global other_shocks_stacked: 	subinstr global other_shocks_stacked "_1993_2007" "", all
global other_shocks_stacked: 	subinstr global other_shocks_stacked "_1990" "", all
global other_shocks_stacked: 	subinstr global other_shocks_stacked "_1970" "", all

* Figure colors *
global main_color    gs15%70
global second_color  gs9%90
global third_color   gs10%70

global inference_bjh=1 /*Set to zero tu run without producing BJH standard errors*/

********************************************************************************
***						Industry-level analysis							     ***
********************************************************************************

/* Main text:
- Figure 1 in the main text: "Industrial robots in the United States and Europe 1993-2007"
- Figure 2 in the main text: "Adjusted penetration of robots in the US and Europe by Industry (1993-2007)"
- Figure 3 in the main text: "Relationship between robots and labor demand across industries (NBER-CES data)"
*/
run "${project}/dofiles/maindo/figure-industry results"

* Main text, Table 1	: "Robots, labor demand, labor share and value added: industry-level results"
run "${project}/dofiles/maindo/table1-industry results"

* Appendix, Figure A1 	: "Adjusted robot penetration and share of replaceable jobs" *
run "${project}/dofiles/appendixdo/appendix-figure replaceable jobs"

* Appendix, Figure A2 	: "Industry pre-trends" *
run "${project}/dofiles/appendixdo/appendix-figure industry pretrends"

* Appendix, Table  A2  	: "Adjusted penetration of robots in the US and in Europe" *
run "${project}/dofiles/appendixdo/appendix-table industry first stage"

* Appendix, Table  A3  	: "Industry-level correlations between adjusted penetration 
* 					  	   of robots and industry characteristics"*
run "${project}/dofiles/appendixdo/appendix-table industry correlates"

* Appendix, Table  A4  	: "Industry-level results: different constructions of the adjusted penetration of robots" *
run "${project}/dofiles/appendixdo/appendix-table industry results with different apr measures"

* Appendix, Table  A5  	: "Industry-level results: Different time periods"*
run "${project}/dofiles/appendixdo/appendix-table industry results for different time periods"

* Appendix, Table  A6  	: "Robots and labor demand: control for other industry trends"  *
run "${project}/dofiles/appendixdo/appendix-table industry control for other trends"

* Appendix, Table  A7  	: "Industry-level results: Labor Share, Value Added and Productivity"*
run "${project}/dofiles/appendixdo/appendix-table industry aggregates"

********************************************************************************
***						Commuting Zone-level analysis					     ***
********************************************************************************

* Main text, Figure 4	: "Geographic distribution of Exposure to Robots"
run "${project}/dofiles/maindo/figure-maps"

* Main text, Figure 5  	: "Exposure to robots and the location of robot integrators"
* Appendix,  Figure A3 	: "First-stage relationship for commuting zones"
* Main text, Figure 6  	: "The effects of robots on employment and wages"
* Main text, Figure 7  	: "Pre-trends in employment and wages"
run "${project}/dofiles/maindo/figures-czone results"

*Main text, Figure 8  - Panel A: "The effects of robots on industries and occupations", Changes in Employment by industry				 
*Appendix, Figure A4  - Panel A: "The effects of robots on industries and occupations - additional estimates", Changes in employment by industry			 
run "${project}/dofiles/maindo/figure-effects by industry"

*Main text, Figure 8  - Panel B: "The effects of robots on industries and occupations", Changes in Employment by occupation				 
*Appendix, Figure A4  - Panel B: "The effects of robots on industries and occupations - additional estimates", Changes in employment by occupation			 
run "${project}/dofiles/maindo/figure-effects by occupation"

* Main text, Figure 9  : "The effects of robots on employment and wages by education and gender"
run "${project}/dofiles/maindo/figure-effects by skill and gender"

* Main text, Figure 10 : "The effects of robots on the wage distribution"
run "${project}/dofiles/maindo/figure-wage distribution"

* Main text, Table 2   : "The effects of robots on employment and wages: long differences" *
* Appendix, Table A31  : "Alternative inference following Borusyak et al. (2018): long differences" *
run "${project}/dofiles/maindo/table2-long differences reduced form"

* Main text, Table 3   : "The effects of robots on employment and wages: stacked differences" *
* Appendix, Table A32  : "Alternative inference following Borusyak et al. (2018): stacked differences" *
run "${project}/dofiles/maindo/table3-stacked differences reduced form"

* Main text, Table 4   : The effects of robots on employment and wages: testing and controlling for pre-trends" *
run "${project}/dofiles/maindo/table4-test and control for pretrends"

* Main text, Table 5   : "The effects of robots on employment and wages: the role of the automotive industry" *
run "${project}/dofiles/maindo/table5-automotive manufacturing"

* Main text, Table 6   : "The effects of robots controlling for capital deepening, IT capital and value added" *
run "${project}/dofiles/maindo/table6-compare to capital deepening and other technologies"

* Main text, Table 7   : "The effects of robots on employment and wages: IV estimates"
* Appendix,  Table A30 : "Alternative inference following Borusyak et al. (2018): IV estimates"
run "${project}/dofiles/maindo/table7-IV estimates"

********************************************************************************
****							Appendix results							****
********************************************************************************

* Appendix, Table A8	: "Exposure to robots and the location of integrators" *
run "${project}/dofiles/appendixdo/appendix-table integrators location"

* Appendix, Table A9 	: "Summary Statistics: Commuting Zone Data" *
* Appendix, Table A10 	: "Relationship between exposure to robots and covariates" * 
run "${project}/dofiles/appendixdo/appendix-table balanced covariates"

/* Appendix, Table A11  : "The effect of robots on employment and wages: exclude the
						  share of employment in light manufacturing and the female share
						  of manufacturing employment from covariates".*/
run "${project}/dofiles/appendixdo/appendix-table light manufacturing"

* Appendix, Table A12 	: "Coefficients for the main covariates in Tables 2 and 3"
run "${project}/dofiles/appendixdo/appendix-table coefficient of other covariates"

* Appendix, Table A13  	: "The effects of robots on employmnet and wages: recent periods"
run "${project}/dofiles/appendixdo/appendix-table more recent periods"

* Appendix, Table A14  	: "The effects of robots on manufacturing and employment"
run "${project}/dofiles/appendixdo/appendix-table transformation of manufacturing"

* Appendix, Table A15  	: "The effects of robots on employment: additional outcomes"
run "${project}/dofiles/appendixdo/appendix-table other employment outcomes"
 
* Appendix, Table A16  	: "The effects of robots on wages: additional outcomes"
run "${project}/dofiles/appendixdo/appendix-table other wage outcomes"
 
* Appendix, Table A17  	: "The effects of robots on government transfers"
run "${project}/dofiles/appendixdo/appendix-table fiscal transfers"

* Appendix, Table A18  	: "The effects of robots on migration, population, and housing prices and rents"
run "${project}/dofiles/appendixdo/appendix-table migration response"
run "${project}/dofiles/appendixdo/appendix-table rents and house prices"

* Appendix, Table A19  	: "The effects of robots on wage and non-wage income"
run "${project}/dofiles/appendixdo/appendix-table income from bea and irs"

* Appendix, Table A20  	: "Pre-trends 1970 - 1990: additional outcomes"
run "${project}/dofiles/appendixdo/appendix-table test for other pretrends"

* Appendix, Table A21  	: "Rotemberg weights"
run "${project}/dofiles/appendixdo/appendix-table compute rotemberg weights"

* Appendix, Table A22 	: "Controlling for the effects of trade"
run "${project}/dofiles/appendixdo/appendix-table role of international trade"

* Appendix, Table A23  	: "The effects of robots and computers on employment and wages"
run "${project}/dofiles/appendixdo/appendix-table other measures of computers and IT"

* Appendix,  Table A24 	: "The effects of robots on employment: alternative constructions of exposure to robots" 
* Appendix,  Table A25 	: "The effects of robots on wages: alternative constructions of exposure to robots" 
run "${project}/dofiles/appendixdo/appendix-table alternative apr measures"

* Appendix, Table A26  	: "The effects of robots on employmnet and wages: the role of outliers"
run "${project}/dofiles/appendixdo/appendix-table robustness to outliers"

* Appendix, Table A27  	: "The effects of robots on employment and wages: additional covariates"
run "${project}/dofiles/appendixdo/appendix-table includes additional covariates"

* Appendix, Table A28  	: "The effects of robots on employment and wages: covariates selected by LASSO"
run "${project}/dofiles/appendixdo/appendix-table lasso with multiple covariates"

* Appendix, Table A29  	: "The effects of robots on employment and wages by gender"
run "${project}/dofiles/appendixdo/appendix-table estimates for men and women"

* Appendix, Table A33  	: "OLS estimates of the relationship between US exposure to robots and employment and wages" 
run "${project}/dofiles/appendixdo/appendix-table ols estimates"














