/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Figure 9 : "EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES BY EDUCATION AND GENDER."
- Panel A: Employment to population ratios
- Panel B: Log hourly wages
- Effects on manufacturing employment by group computed but not reported in final version

4.15.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Create empty dataset which will collect the estimates*
clear 
set obs 100
gen outcome=""
gen type=""
gen b=.
gen se=.
gen male_b=.
gen male_se=.
gen female_b=.
gen female_se=.
save "${project}/results/inequality_estimates_longdif.dta", replace

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
gen exposure_robots=expof_${expomes}93_07

local j=1


********************************************************************************
**** Long Differences Effects of Robots on Employment in Manufacturing, 	 ***
**** Employment in Private Sector and Hourly Wage by gender/Skill level      ***
********************************************************************************

**** Loop through the different outcomes
foreach depvar in emppriv empman {
**** Loop through the different skill levels (All, masters, college, some colege, high school, less than high school  ***
foreach type in all pc fc sc hs lh{

* Estimate for ALL the individuals
reg d_`depvar'_`type'_1990_2008 exposure_robots  $demographics $industry_shares $other_shocks i.division [w=ipums_pop_1990], cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace outcome="`depvar'" in `j'
replace type="`type'" in `j'
replace b=_b[exposure_robots] in `j'
replace se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

* Estimate for MEN
reg d_`depvar'_`type'_m_1990_2008 exposure_robots  $demographics $industry_shares $other_shocks i.division [w=ipums_pop_1990], cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace male_b=_b[exposure_robots] in `j'
replace male_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

*Estimate for WOMEN
reg d_`depvar'_`type'_f_1990_2008 exposure_robots  $demographics $industry_shares $other_shocks i.division [w=ipums_pop_1990], cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace female_b=_b[exposure_robots] in `j'
replace female_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

local j=`j'+1

} 
} 



********************************************************************************
**** 				Effects of Robots on Log Hourly Wage					 ***
****    Long Difference Estimates by Gender & by Gender AND skill Level		 ***
********************************************************************************


foreach depvar in hrwage_ln {

***********************    Estimates By Gender    ******************************
*Long differences*
use czone d_`depvar'_1990_2008 wage_earners_* group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(expof_${expomes}93_07 $other_shocks )
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
split group, p("_")
rename group1 gender
rename group5 education
gen type=""
replace type="lh" if education=="lschool" 
replace type="hs" if education=="hschool"
replace type="sc" if education=="somcoll"
replace type="fc" if education=="college"
replace type="pc" if education=="masters" 

encode group, gen(group_id)
encode state, gen(stcode)
gen detroit=(czone==11600)
gen exposure_robots=expof_${expomes}93_07

* Estimate for ALL the individuals
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace outcome="`depvar'_bygroup" in `j'
replace type="all" in `j'
replace b=_b[exposure_robots] in `j'
replace se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

* Estimate for MEN
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if gender=="men", a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace male_b=_b[exposure_robots] in `j'
replace male_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

* Estimate for WOMEN
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if gender=="women", a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace female_b=_b[exposure_robots] in `j'
replace female_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore
local j=`j'+1


********************** Estimates by Gendere AND Skill LEVEL *********************
foreach type in pc fc sc hs lh{

* Estimate for ALL individuals
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if type=="`type'", a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace outcome="`depvar'_bygroup" in `j'
replace type="`type'" in `j'
replace b=_b[exposure_robots] in `j'
replace se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

* Estimate for MEN
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if type=="`type'" & gender=="men", a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace male_b=_b[exposure_robots] in `j'
replace male_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore

* Estimate for WOMEN
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if type=="`type'" & gender=="women", a(group_id) cluster(stcode)
preserve
use "${project}/results/inequality_estimates_longdif.dta", clear
replace female_b=_b[exposure_robots] in `j'
replace female_se=_se[exposure_robots] in `j'
save "${project}/results/inequality_estimates_longdif.dta", replace
restore
local j=`j'+1

}
}



***********************    Plot GRAPH    *************************
use "${project}/results/inequality_estimates_longdif.dta", clear
gen offset=-1
gen offset_male=0
gen offset_female=1

* Create different position on the x-axis for different skill level
gen position=0 if type=="all"		// All workers
replace position=4  if type=="lh"	// Less than High School
replace position=8  if type=="hs"	// High School degree
replace position=12  if type=="sc" 	// Some College
replace position=16  if type=="fc"	// College and Professional Degrees
replace position=20 if type=="pc" 	// Masters and Doctoral Degrees

gen number=position+offset
gen number_male=position+offset_male
gen number_female=position+offset_female

** Create title for two different panels in the figure **
gen panel=""
replace panel="Panel A. employment to population ratios" if outcome=="emppriv"
replace panel="Panel B. log hourly wages" if outcome=="hrwage_ln_bygroup"
keep if panel!=""

** Store estimates for confidence interval **
gen low=b-1.95*se
gen high=b+1.95*se
gen male_low=male_b-1.96*male_se
gen male_high=male_b+1.96*male_se
gen female_low=female_b-1.96*female_se
gen female_high=female_b+1.96*female_se

** Generate base lines for the bar graph *8
gen zero=0
forvalues j=1(1)6{
gen bar`j'=.
replace bar`j'=4*(`j'-1)-1.5 in 1
replace bar`j'=4*(`j'-1)+1.5 in 2
replace bar`j'=4*(`j'-1)-1.5 in 6
replace bar`j'=4*(`j'-1)+1.5 in 7
replace bar`j'=4*(`j'-1)-1.5 in 11
replace bar`j'=4*(`j'-1)+1.5 in 12
}


twoway (bar b number, barwidth(0.7) fcolor("${third_color}") lcolor(black) lwidth(vthin)) (rcap low high number, lcolor(black) lwidth(vthin)) ///
       (bar male_b number_male, barwidth(0.7) fcolor("${second_color}") lcolor(black) lwidth(vthin))  (rcap male_low male_high number_male, lcolor(black) lwidth(vthin)) ///
	   (bar female_b number_female, barwidth(0.7) fcolor("${main_color}") lcolor(black) lwidth(vthin)) (rcap female_low female_high number_female, lcolor(black) lwidth(vthin)) ///
	   (line zero bar1, lcolor(black) lwidth(vthin)) ///
	   (line zero bar2, lcolor(black) lwidth(vthin)) ///
	   (line zero bar3, lcolor(black) lwidth(vthin)) ///
	   (line zero bar4, lcolor(black) lwidth(vthin)) ///
	   (line zero bar5, lcolor(black) lwidth(vthin)) ///
	   (line zero bar6, lcolor(black) lwidth(vthin)) ///
	   , by(panel, legend(on position(5)) noixtick ixaxes rows(2)  note("")  yrescale graphregion(ilcolor(white) fcolor(white)) ) ///
	   ylabel(#5, angle(horizontal)) xscale(noline) xscale(alt) xlabel(0 "All workers" 4 `""Less than" "high school""' 8 `""High school" "degree""' 12 "Some college" 16 `""College and" "professional degrees""' 20 `""Masters and" "doctoral degrees""', labsize(small) noticks) xsize(9) ysize(6) ///
       legend(rows(1) region(lwidth(none) lcolor(none)) order(1 "Men and women" 3 "Men" 5 "Women") size(vsmall)) subtitle(, position(11) nobox size(medsmall) fcolor() color(dknavy)) 	
graph export "$project/results/figure_inequality_longdifs.png", as(png) width(3000)  replace

