/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Figure 5  : EXPOSURE TO ROBOTS AND THE LOCATION OF ROBOTS INTEGRATORS 
Figure A3 : FIRST-STAGE RELATIONSHIP FOR COMMUTING ZONES
Figure 6  : THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES	
Figure 7  : PRE-TRENDS IN EMPLOYMENT AND WAGES.

5.21.2018 (revised 4/30/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*************************************************************************
* Figure 5: Location of Robot Integrators  								*
* Figure A3: First-stage relationship for commuting zones 				*
*************************************************************************

***   Define program to plot residuals    ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=2*floor(r(max)/2)+2
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=., mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))


end


*** Prepare dataset ****
use   "${project}/clean_data/czones_integrators.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(2 3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen full_name=name_czone

*Figure 5: Exposure to robots and the location of robot integrators. *
resid_plot log_num_int expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $other_shocks $region_effects) xtitle(Exposure to robots) ytitle(log of one plus robot integrators)
graph export "$project/results/figure_integrators.png", as(png) width(3000)  replace

*Figure A3: First-stage relationship for commuting zones *
gen us_adoption=(expof_us_adj04_07)*14/3
resid_plot  us_adoption expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $other_shocks $region_effects) xtitle(Exposure to robots) ytitle(US exposure to robots)
graph export "$project/results/figure_first_stage.png", as(png) width(3000)  replace

*************************************************************************
* Figure 6: panels A and C												*
* The Effects of Robots on Employment 									*
*************************************************************************

***   Define program to plot residuals - Long Differences model   ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=2*floor(r(max)/2)+2
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=. , mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))

end

***   Define program to plot residuals - Stacked Differences model   ***
cap program drop resid_plot_stacked
program define resid_plot_stacked, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=2*floor(r(max)/2)+2
	
	twoway (scatter `projected_y' `x_var' `wt' if year==2000 & `projected_y'!=.  , mcolor("${second_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (scatter `projected_y' `x_var' `wt' if year==1990 & `projected_y'!=. , mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${second_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))
	   
end

***    Long differences    ***
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen full_name=name_czone

*Figure 6 Panel A: Exposure to Robots and Changes in the Employment to Population Ratio (Long Differences)*
resid_plot d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $other_shocks $region_effects) xtitle("Exposure to robots") ytitle("Change in employment to population ratio 1990-2007")
graph export "$project/results/figure_longdif_emppriv.png", as(png) width(3000)  replace

***    Stacked differences    ***
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year
gen full_name=name_czone+" 1990" if year==1990
replace full_name=name_czone+" 2000" if year==2000

*Figure 6 Panel C: Exposure to Robots and Changes in the Employment to Population Ratio (Stacked Differences)*
resid_plot_stacked d_emppriv expof_${expomes} [w=ipums_pop_1990], controls($demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year) xtitle("Exposure to robots") ytitle("Change in employment to population ratio")
graph export "$project/results/figure_stacked_emppriv.png", as(png) width(3000)  replace

*************************************************************************
* Figure 6: panels B and D												*
* The Effects of Robots on Wages	 									*
*************************************************************************


***   Define program to plot residuals - Long Differences model   ***

cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls' i.group_id `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	preserve 
	keep if `est_sample'==1
	* Collapse the data at Czone level to plot them
	collapse (rawsum) wage_earners_1990 (mean) `projected_y' `x_var' tag_exposure `wt', by(full_name) 
	
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=2*floor(r(max)/2)+2
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=. , mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))

		   restore

end

***   Define program to plot residuals - Stacked Differences model   ***
cap program drop resid_plot_stacked
program define resid_plot_stacked, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls' i.group_id##i.year `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	preserve 
	keep if `est_sample'==1
	* Collapse the data at Czone level to plot them
	collapse (rawsum) wage_earners_1990 (mean) `projected_y' `x_var' tag_exposure `wt', by(full_name year) 
	
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=2*floor(r(max)/2)+2
	
	twoway (scatter `projected_y' `x_var' `wt' if year==2000& `projected_y'!=. , mcolor("${second_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (scatter `projected_y' `x_var' `wt' if year==1990& `projected_y'!=. , mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${second_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))
    
	restore

end

***    Long differences    ***
use czone group d_hrwage_ln_1990_2008 wage_earners_1990 using "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)
gen full_name=name_czone

*Figure 6 Panel B: Exposure to Robots and Changes in Log Hourly Wages (Long Differences)*
resid_plot d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990], controls($demographics $industry_shares $other_shocks $region_effects) xtitle("Exposure to robots") ytitle("Change in log hourly wages 1990-2007")
graph export "$project/results/figure_longdif_hrwage.png", as(png) width(3000)  replace

***    Stacked differences    ***
use czone year group d_hrwage_ln wage_earners_1990 using "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)
gen full_name=name_czone+" 1990" if year==1990
replace full_name=name_czone+" 2000" if year==2000

*Figure 6 Panel D: Exposure to Robots and Changes in Log Hourly Wages (Stacked Differences)*
resid_plot_stacked d_hrwage_ln expof_${expomes} [w=wage_earners_1990], controls($demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year) xtitle("Exposure to robots") ytitle("Change in log hourly wages")
graph export "$project/results/figure_stacked_hrwage.png", as(png) width(3000)  replace

*************************************************************************
* Figure 7: Placebo Test												*
* Pre-trends in Employment and Wages									*
*************************************************************************

* Employment *
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=5*floor(r(max)/5)+5
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=., mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))


end

* Prepare dataset
use "${project}/clean_data/outcomes_placebo_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate

* Replace Controls in Macro with 1970 in place of 1990
global industry_shares_1970: subinstr global industry_shares "_1990" "_1970", all
global demographics_1970: subinstr global demographics "_1990" "_1970", all
gen full_name=name_czone

*Figure 7 TOP Panel: Exposure to Robots and Changes in PAST Employment To Population Ratio *
resid_plot d_emppriv_1970_1990 expof_${expomes}93_07  [w=ipums_pop_1970], controls( $demographics_1970 $industry_shares_1970 $other_shocks_1970 $region_effects) xtitle("Exposure to robots") ytitle("Past change in employment to population ratio 1970-1990")
graph export "$project/results/figure_placebo_emppriv.png", as(png) width(3000)  replace

* Wages *
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls' i.group_id `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	preserve 
	keep if `est_sample'==1
	collapse (rawsum) wage_earners_1970 (mean) `projected_y' `x_var' tag_exposure `wt', by(full_name) 
	
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if tag_exposure==1
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=(1-tag_exposure)

	
	quietly: sum `x_var' `if', d
	local min=r(min)
	local max=5*floor(r(max)/5)+5
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=. , mcolor("${main_color}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(full_name) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(2)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))
    restore

end

* Prepare dataset
use czone group d_hrwage_ln_1970_1990 wage_earners_1970 using "${project}/clean_data/outcomes_placebo_group.dta", clear
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks_1970)
merge m:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

* Replace Controls in Macro with 1970 in place of 1990
global industry_shares_1970: subinstr global industry_shares "_1990" "_1970", all
global demographics_1970: subinstr global demographics "_1990" "_1970", all
gen full_name=name_czone

*Figure 7 BOTTOM Panel: Exposure to Robots and Changes in PAST Log Hourly Wages *
resid_plot d_hrwage_ln_1970_1990 expof_${expomes}93_07  [w=wage_earners_1970], controls( $demographics_1970 $industry_shares_1970 $other_shocks_1970 $region_effects) xtitle("Exposure to robots") ytitle("Past change in log hourly wages 1970-1990")
graph export "$project/results/figure_placebo_hrwage.png", as(png) width(3000)  replace

