/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 1: "Robots, labor demand, labor share and value added: industry-level results"

The table presents estimates of the relationship between adjusted penetration of
robots and wage bill, employment, value added and labor share across US industries.

5.21.2018 (revised 4/1/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

**********************
**Panel A: Wage bill**
**********************

*******  Columns 1-4: Long differences   *******

use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007

*Column 1: CBP log wage bill*
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
reg depvar change_robots  [w=cbp_emp1993], r 
estimates store e1

*Column 2: CBP log wage bill + industry shares + china*
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp1993], r 
estimates store e2

*Column 3: NBER within manufacturing: log wage bill + industry share + china*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e3

*Column 4: NBER production workers within manufacturing: log wage bill + industry shares + china*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e4

*Column 10: BEA Annualized log Value added: industry shares + china*
cap drop depvar
gen depvar=100*(ln(beaio_VA07)-ln(beaio_VA92))/15
reg depvar change_robots change_china manufacturing light_manuf [w=beaio_VA92], r 
estimates store e10

********  Columns 5-9: Stacked differences   *********

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure: 1993-2000 and 2000-2007
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure 1993-2000 and 2000-2007
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1

*Column 5: CBP log wage bill + period dummies*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
reg depvar change_robots i.period [w=cbp_emp1993], r cluster(indcode)
estimates store e5

*Column 6: CBP log wage bill + period dummies + industry shares + china*
reg depvar change_robots change_china manufacturing light_manuf i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e6

*Column 7: CBP log wage bill + period dummies + industry shares + china + industry dummies*
reg depvar change_robots change_china i.indcode i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e7

*Column 8: NBER within manufacturing: log wage bill + period dummies + industry shares + china*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e8

*Column 9: NBER within manufacturing: log wage bill of production workers + period dummies + industry shares + china*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993], r 
estimates store e9

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 e9 e10 using "$project/results/table1_wagebill.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ }"  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots ) 

***********************
**Panel B: Employment**
***********************

*******  Columns 1-4: Long differences   *******

use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007

*Column 1: CBP log employment*
gen depvar=100*(ln(cbp_emp2007)-ln(cbp_emp1993))
reg depvar change_robots  [w=cbp_emp1993], r 
estimates store e1

*Column 2: CBP log employment + industry shares + china*
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp1993], r 
estimates store e2

*Column 3: NBER within manufacturing: log employment + industry shares + china*
cap drop depvar
gen depvar=100*(ln(nber_emp2007)-ln(nber_emp1993))
reg depvar change_robots change_china light_manuf [w=nber_emp1993], r 
estimates store e3

*Column 4: NBER production workers w/in manufacturing: log employment + industry shares + china
cap drop depvar
gen depvar=100*(ln(nber_prode2007)-ln(nber_prode1993))
reg depvar change_robots change_china light_manuf [w=nber_emp1993], r 
estimates store e4

*Column 10: BEA Labor Shares: industry shares + china*
cap drop depvar
gen depvar=100*(beaio_labsh07-beaio_labsh92)
reg depvar change_robots change_china manufacturing light_manuf [w=beaio_VA92], r
estimates store e10


********  Columns 5-9: Stacked differences   *********

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure: 1993-2000 and 2000-2007
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure 1993-2000 and 2000-2007
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1

*Column 5: CBP log employment + period dummies*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_emp2007)-ln(cbp_emp2000)) if period==2
replace depvar=100*(ln(cbp_emp2000)-ln(cbp_emp1993)) if period==1
reg depvar change_robots i.period [w=cbp_emp1993], r cluster(indcode)
estimates store e5

*Column 6: CBP log employment + period dummies + industry shares + china*
reg depvar change_robots change_china manufacturing light_manuf i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e6

*Column 7: CBP log employment + period dummies + industry shares + industry dummies + china*
reg depvar change_robots change_china i.indcode i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e7

*Column 8: NBER log employment within manufacturing + period dummies + industry shares + china*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_emp2007)-ln(nber_emp2000)) if period==2
replace depvar=100*(ln(nber_emp2000)-ln(nber_emp1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e8

*Column 9: NBER log employment of production workers within manufacturing + period dummies + industry shares + china *
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_prode2007)-ln(nber_prode2000)) if period==2
replace depvar=100*(ln(nber_prode2000)-ln(nber_prode1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993], r 
estimates store e9

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 e9 e10 using "$project/results/table1_employment.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots ) 


