/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 4  : "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: TESTING AND CONTROLLING FOR PRE-TRENDS"

The tables present estimates of the effects of exposure to robots on employment
and wages, as well as estimates on contemporary changes in employment and wages
controlling for past changes in these outcomes.

		 
5.21.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


*********************************************************************************
*** Panel A: Dep. Variable is Past changes in labor market outcomes	 (1970-1990)*
****							(Placebo)									*****
*********************************************************************************


****** Columns 1 - 4 : Change in the employment to population ratio *******
use "${project}/clean_data/outcomes_placebo_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate

* Column 1: Baseline Covariates
reg d_emppriv_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e1emp

* Column 2: Baseline covariates + trade and routine jobs 
reg d_emppriv_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=ipums_pop_1970], r cluster(state)
estimates store e2emp

* Column 3: Excludes zones with highest exposure to robots
reg d_emppriv_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=ipums_pop_1970] if tag_exposure==1, r cluster(state)
estimates store e3emp

* Column 4: Unweighted
reg d_emppriv_1970_1990 expof_${expomes}93_07 $demographics_1970 $industry_shares_1970 $other_shocks $region_effects, r cluster(state)
estimates store e4emp


****** Columns 5 - 8 : Change in log hourly wages 	 *******
use czone d_hrwage_ln_1970_1990  nat_earners_weight_1970 wage_earners_1970 group using  "${project}/clean_data/outcomes_placebo_group.dta", clear
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure  $other_shocks expof_${expomes}93_07)
merge m:1 czone using "${project}/clean_data/covariates_1970.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

* Column 5: Baseline Covariates
reghdfe d_hrwage_ln_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e1wages

* Column 6: Baseline covariates + trade and routine jobs 
reghdfe d_hrwage_ln_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=wage_earners_1970], absorb(i.group_id) cluster(stcode)
estimates store e2wages

* Column 7: Excludes zones with highest exposure to robots
reghdfe d_hrwage_ln_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=wage_earners_1970] if tag_exposure==1, absorb(i.group_id) cluster(stcode)
estimates store e3wages

* Column 8: Unweighted
reghdfe d_hrwage_ln_1970_1990 expof_${expomes}93_07  $demographics_1970 $industry_shares_1970 $other_shocks $region_effects [w=nat_earners_weight_1970], absorb(i.group_id) cluster(stcode)
estimates store e4wages

*Export Table 4, Panel A*
estout e1emp e2emp e3emp e4emp e1wages e2wages e3wages e4wages using "$project/results/table4_placebo.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "\multirow{2}{=}{Exposure to robots in subsequent period, 1993-2007}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07 ) ///
order(expof_${expomes}93_07 ) 


*********************************************************************************
*** Panel B: Controlling for exposure to industry trends between 1970 and 1990  *
*********************************************************************************

****** Columns 1 - 4 : Change in the employment to population ratio *******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Column 1: Baseline Covariates
reg d_emppriv_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1emp

* Column 2: Baseline covariates + trade and routine jobs 
reg d_emppriv_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2emp

* Column 3: Excludes zones with highest exposure to robots
reg d_emppriv_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e3emp

* Column 4: Unweighted
reg d_emppriv_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e4emp



****** Columns 5 - 8 : Change in log hourly wages 	 *******
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using "${project}/clean_data/outcomes_longdif_group.dta", clear
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expo_decline*   $other_shocks expof_${expomes}93_07)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

* Column 5: Baseline Covariates
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $region_effects [w=wage_earners_1990], absorb(i.group_id) cluster(stcode)
estimates store e1wages

* Column 6: Baseline covariates + trade and routine jobs 
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(i.group_id) cluster(stcode)
estimates store e2wages

* Column 7: Excludes zones with highest exposure to robots
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id) cluster(stcode)
estimates store e3wages

* Column 8: Unweighted
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 expo_decline_ifr_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(i.group_id) cluster(stcode)
estimates store e4wages

*Export Table 4, Panel B*
estout e1emp e2emp e3emp e4emp e1wages e2wages e3wages e4wages using "$project/results/table4_bartik.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots" expo_decline_ifr_1970_1990 "\multirow{2}{=}{Exposure to industry trends 1970-1990}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07 expo_decline_ifr_1970_1990) ///
order(expof_${expomes}93_07 expo_decline_ifr_1970_1990) 



******************************************************************************************
*** Panel C: Controlling for the change in the dependent variable between 1970 and 1990  *
******************************************************************************************

****** Columns 1 - 4 : Change in the employment to population ratio *******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/outcomes_placebo_czone.dta",  assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Column 1: Baseline Covariates
reg d_emppriv_1990_2008 expof_${expomes}93_07 d_emppriv_1970_1990 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1emp

* Column 2: Baseline covariates + trade and routine jobs 
reg d_emppriv_1990_2008 expof_${expomes}93_07 d_emppriv_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2emp

* Column 3: Excludes zones with highest exposure to robots
reg d_emppriv_1990_2008 expof_${expomes}93_07 d_emppriv_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e3emp

* Column 4: Unweighted
reg d_emppriv_1990_2008 expof_${expomes}93_07 d_emppriv_1970_1990 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e4emp

****** Columns 5 - 8 : Change in log hourly wages 	 *******
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using "${project}/clean_data/outcomes_longdif_group.dta", clear
merge 1:1 czone group using "${project}/clean_data/outcomes_placebo_group.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure  $other_shocks expof_${expomes}93_07)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

* Column 5: Baseline Covariates
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 d_hrwage_ln_1970_1990 $demographics $industry_shares $region_effects [w=wage_earners_1990], absorb(i.group_id) cluster(stcode)
estimates store e1wages

* Column 6: Baseline covariates + trade and routine jobs 
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 d_hrwage_ln_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(i.group_id) cluster(stcode)
estimates store e2wages

* Column 7: Excludes zones with highest exposure to robots
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 d_hrwage_ln_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id) cluster(stcode)
estimates store e3wages

* Column 8: Unweighted
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 d_hrwage_ln_1970_1990 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(i.group_id) cluster(stcode)
estimates store e4wages

*Export Table 4, Panel C*
estout e1emp e2emp e3emp e4emp e1wages e2wages e3wages e4wages using "$project/results/table4_pretrends.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07 ) ///
order(expof_${expomes}93_07 ) 
