/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 5  : "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: THE ROLE OF THE 
			AUTOMOTIVE INDUSTRY"

The tables present estimates of the effects of exposure to robots separately for
the automotive industry and other industries.

5.21.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*** Panel A: Change in the employment to population ratio					****
********************************************************************************

****** Columns 1 - 3 : Long Differences 1990 - 2007
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Exposure to robots in automotive industry
gen expo_car=expoc_${expomes}93_07
* Exposure to robots in other indutries
gen expo_other=expon_${expomes}93_07

* Column 1: Census division dummies
reg d_emppriv_1990_2008 expo_car expo_other $region_effects [w=ipums_pop_1990], r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e1

* Column 2: Census division dummies + baseline covariates
reg d_emppriv_1990_2008 expo_car expo_other $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e2

* Column 3: Census division dummies + baseline covariates, regression not weighted by population
reg d_emppriv_1990_2008 expo_car expo_other $demographics $industry_shares  $other_shocks $region_effects, r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e3

****** Columns 4 - 6 : Stacked differences 1990 - 2000 and 2000 - 2007
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Define panel structure for stacked differences
xtset czone year, delta(10)
sort czone year

* Generate exposure to robots in the automotive industry
gen expo_car=expoc_${expomes}
* Generate exposure to robots in other industries
gen expo_other=expon_${expomes}

* Column 4: Time period and Census division dummies
reg d_emppriv expo_car expo_other  $region_effects i.year [w=ipums_pop_1990], r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e4

* Column 5: Time period, Census division dummies and baseline covariates
reg d_emppriv expo_car expo_other  $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e5

* Column 6: Time period, Census division dummies and baseline covariates, regression not weighted by population
reg d_emppriv expo_car expo_other  $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e6

* Export Table 5, Panel A
estout e1 e2 e3 e4 e5 e6  using "$project/results/table5_emppriv.tex", style(tex) ///
varlabels(expo_car "\multirow{2}{=}{Exposure to robots in automotive industry}" expo_other "\multirow{2}{=}{Exposure to robots in other industries}" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(pval_equality N r2, fmt(%7.2f %7.0f %7.2f) labels("Test for equality of coefficients (p-value)" "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expo_car expo_other) ///
order(expo_car expo_other) 

********************************************************************************
*** Panel B: Change in log hourly wages										****
********************************************************************************

****** Columns 1 - 3 : Long Differences 1990 - 2007
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks expoc_${expomes}93_07 expon_${expomes}93_07)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Exposure to robots in automotive industry
gen expo_car=expoc_${expomes}93_07
* Exposure to robots in ohter industries
gen expo_other=expon_${expomes}93_07

* Column 1: Census division dummies
reghdfe d_hrwage_ln_1990_2008 expo_car expo_other $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e1

* Column 2: Census division dummies + baseline covariates
reghdfe d_hrwage_ln_1990_2008 expo_car expo_other $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e2

* Column 3: Census division dummies + baseline covariates, regression not weighted by population
reghdfe d_hrwage_ln_1990_2008 expo_car expo_other $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e3

****** Columns 4 - 6 : Stacked differences 1990 - 2000 and 2000 - 2007
set matsize 5000
use czone year d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(expo_task* $other_shocks_stacked expoc_${expomes} expon_${expomes} )
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Generate exposure to robots in the automotive industry
gen expo_car=expoc_${expomes}
* Generate exposure to robots in other industries
gen expo_other=expon_${expomes}

* Column 4: Time period and Census division dummies
reghdfe d_hrwage_ln expo_car expo_other $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e4

* Column 5: Time period, Census division dummies and baseline covariates
reghdfe d_hrwage_ln expo_car expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e5

* Column 6: Time period, Census division dummies and baseline covariates, regression not weighted by population
reghdfe d_hrwage_ln expo_car expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
test _b[expo_car]==_b[expo_other]
estadd scalar pval_equality=r(p)
estimates store e6

*Export table5, Panel B*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table5_hrwage_ln.tex", style(tex) ///
varlabels(expo_car "\multirow{2}{=}{Exposure to robots in automotive industry}" expo_other "\multirow{2}{=}{Exposure to robots in other industries}" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(pval_equality N r2, fmt(%7.2f %7.0f %7.2f) labels("Test for equality of coefficients (p-value)" "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expo_car expo_other) ///
order(expo_car expo_other) 





