/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 6  : "THE EFFECTS OF ROBOTS CONTROLLING FOR CAPITAL DEEPENING, IT CAPITAL 
			AND VALUE ADDED"

The tables present estimates of the effects of exposure to robots, capital accumulation,
IT capital and value-added on employment and wages.

5.21.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Loop through the different controls that will be added one at a time in each specification:
* Panel A: adds Exposure to capital
* Panel B: adds Exposure to itcapital
* Panel C: adds Exposure to industry value added
foreach trend in capital itcapital vadded {

* For each regressor create the appropriate control for the long-difference and stacked difference analysis
if "`trend'"=="capital"{
local expo_long   expo_capital_1990_2007
local expo_stacked expo_capital
local label "Exposure to capital"
}
else if "`trend'"=="itcapital"{
local expo_long    expo_itcapital_1990_2007
local expo_stacked expo_itcapital
local label "Exposure to IT capital"
}
else if "`trend'"=="vadded"{
local expo_long     expo_vadded_io_1992_2007
local expo_stacked  expo_vadded_io 
local label "Exposure to industry value added"
}
********************************************************************************
**** 		Columns 1 -4 Change in the Employment to Population Ratio  		****
********************************************************************************

**** Columns 1 - 2 : Long differences ***
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Exposure to robots between 1993 and 2007 (Long Diff.)
gen exposure_robots=expof_${expomes}93_07
* Exposure to alternative control (capital, IT capital or value added) for long-difference analysis
gen expo_other=`expo_long'
sum expo_other [w=ipums_pop_1990]

* Column 1: Baseline Covariates, estimate weighted by population
reg d_emppriv_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Baseline Covariates, estimate Same weight to all czones
reg d_emppriv_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e2

**** Columns 3 - 4 : Stacked differences ***
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Exposure to robots between 1993 - 2000 and 2007 - 2007 (Stacked Diff.)
gen exposure_robots=expof_${expomes}
* Exposure to alternative control (capital, IT capital or value added) for stacked-difference analysis
gen expo_other=`expo_stacked'

* Column 3: Baseline Covariates, Time period dummies, estimate weighted by population
reg d_emppriv exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e3

* Column 4: Baseline Covariates, Time period dummies, estimate Same weight to all czones
reg d_emppriv exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e4

********************************************************************************
**** 		Columns 5 - 8 Change in Log hourly wage					  		****
********************************************************************************

**** Columns 5 - 6 : Long differences ***
use czone d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks expof_${expomes}93_07 expo_capital* expo_itcapital* expo_vadded* )
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Exposure to robots between 1993 and 2007 (Long Diff.)
gen exposure_robots=expof_${expomes}93_07
* Exposure to alternative control (capital, IT capital or value added) for long-difference analysis
gen expo_other=`expo_long'

* Column 5: Baseline Covariates, estimate weighted by population
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Baseline Covariates, estimate Same weight to all czones
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

**** Columns 7 - 8 : Stacked differences ***
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing( $other_shocks_stacked expof_${expomes} expo_capital* expo_itcapital* expo_vadded* )
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Exposure to robots between 1993 - 2000 and 2007 - 2007 (Stacked Diff.)
gen exposure_robots=expof_${expomes}
* Exposure to alternative control (capital, IT capital or value added) for stacked-difference analysis
gen expo_other=`expo_stacked'

* Column 7: Baseline Covariates, Time period dummies, estimate weighted by population
reghdfe d_hrwage_ln exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e7

* Column 8: Baseline Covariates, Time period dummies, estimate Same weight to all czones
reghdfe d_hrwage_ln exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e8

*Export Panel A, B, C of Table 6*
estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table6_`trend'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" expo_other "\multirow{2}{=}{`label'}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots  expo_other ) ///
order(exposure_robots expo_other ) 

}
